@@ -142,6 +142,18 @@ class Corpus(object):
     def __init__(self, basePath):
         self.basePath = basePath
 
+    def getArticle(self, articleId, subcorpus):
+        filepath = self.basePath + "/" + subcorpus
+        print("Filepath:", filepath)
+
+        su = Subcorpus()
+        su.read(filepath)
+
+        for a in su.articles:
+            if a.id == articleId:
+                return a
+        return False
+
     def getSubcorpora(self):   
         liste = []
         for root, dirs, files in os.walk(self.basePath):
@@ -168,5 +180,10 @@ class Corpus(object):
 
 
 if __name__ == "__main__":
+    corpus = Corpus("/data/wp/2020/annotated")
+    a = corpus.getArticle(4184, "AA/wiki_83")
+
+    a.display()
+
     print("These are the objects for the wp-toolbox, call them from your own applications!")
 
